@@ -28,6 +28,12 @@ merge_list = function(x, y) {
   x
 }
 
+to_json = function(x, ..., auto_unbox = TRUE, null = 'null') {
+  jsonlite::toJSON(x, ..., auto_unbox = auto_unbox, null = null)
+}
+
 # don't prefer the port 4321 (otherwise we may see the meaningless error message
 # "createTcpServer: address already in use" too often)
 random_port = function() servr::random_port(NULL)
+
+`%n%` = knitr:::`%n%`
